pub struct HeaderInfo {
pub block_hash: Hash,
pub timestamp: u64,
pub difficulty: Difficulty,
pub secondary_scaling: u32,
pub is_secondary: bool,
pub prev_timespan: u64,
}Expand description
Minimal header information required for the Difficulty calculation to take place
Fields
block_hash: HashBlock hash, ZERO_HASH when this is a sythetic entry.
timestamp: u64Timestamp of the header, 1 when not used (returned info)
difficulty: DifficultyNetwork difficulty or next difficulty to use
secondary_scaling: u32Network secondary PoW factor or factor to use
is_secondary: boolWhether the header is a secondary proof of work
prev_timespan: u64timespan of the previous block of the same algorithm type
Implementations
Sourceimpl HeaderInfo
impl HeaderInfo
Sourcepub fn new(
block_hash: Hash,
timestamp: u64,
difficulty: Difficulty,
secondary_scaling: u32,
is_secondary: bool,
prev_timespan: u64,
) -> HeaderInfo
pub fn new( block_hash: Hash, timestamp: u64, difficulty: Difficulty, secondary_scaling: u32, is_secondary: bool, prev_timespan: u64, ) -> HeaderInfo
Default constructor
Sourcepub fn from_ts_diff(timestamp: u64, difficulty: Difficulty) -> HeaderInfo
pub fn from_ts_diff(timestamp: u64, difficulty: Difficulty) -> HeaderInfo
Constructor from a timestamp and difficulty, setting a default secondary PoW factor
Sourcepub fn from_diff_scaling(
difficulty: Difficulty,
secondary_scaling: u32,
) -> HeaderInfo
pub fn from_diff_scaling( difficulty: Difficulty, secondary_scaling: u32, ) -> HeaderInfo
Constructor from a difficulty and secondary factor, setting a default timestamp